module.exports = class ZebedeeAdventurerGuild {
	constructor() {
		this.id = this.constructor.name;
		this.name = "The Adventurer's Guild";
		this.description = "Well-worn stone floors and dark wooden rafters enclose a musky, exciting smell of adventure. There is a roaring fire in a large {hint}fireplace{/hint} to the west, surrounded by various cosy armchairs and couches. A battered wooden {hint}counter{/hint} stands against the eastern wall, with various guildmarms attending the adventurers. You can see a wide wooden staircase to the south, leading to the upper levels of the guild.";
		this.filename = "zebedee/adventurerguild.js";
		this.type = "room";
		this.items = [];
		this.mobiles = [];
		this.roomExpires = 0;
		this.resetDelay = 3000000;
		this.roomExits = ["north", "west", "east", "up"];
	}

	mud_reset(time) {
		switch(parseInt(Math.random() * 2)) {
			case 0:
				libs.Output.toRoom(this.id, "A group of jovial adventurers laugh and head towards the cozy lounge.");
			break;
			case 1:
			default:
				libs.Output.toRoom(this.id, "A few adventurers jostle past as they approach the guild counter.");
			break;
		}
		world.mud_replaceRoomItem(this.id, "WoodenSword");
		
		this.roomExpires = time + this.resetDelay;
	}

	mud_tick(time) {
		if(time >= this.roomExpires) {
			this.mud_reset(time);
		}
	}

	mud_getName() {
		return this.name;
	}

	mud_getDescription() {
		return this.description;
	}

	look(room, mobile, input) {
		switch(input[0]) {
			case "fireplace":
				libs.Output.toMobile(mobile.id, "A modest fire looks out of place in the massive stone fireplace against the far wall. Many adventurers are standing or reclined near the fireplace, animatedly discussing their spoils or quests.");
				return true;
			case "armchairs":
			case "armchair":
				libs.Output.toMobile(mobile.id, "The crushed velvet elegantly draped over the dark stained wood of the armchairs have seen better days, many patches left bald from an idle hand or heavy bottom. They do, however, look incredibly welcoming and exceedingly comfy.");
				return true;
			case "counter":
				libs.Output.toMobile(mobile.id, "You can't see the counter too well from here due to the throngs of inquisitive adventurers crowding up to it. It appears to be a little worse for the wear but incredibly durable, withstanding the demands of so many rough and tumble explorers.");
				return true;
		}
	}

	вид(room, mobile, input) {
		switch(input[0]) {
			case "прилавок":
				libs.Output.toMobile(mobile.id, "Отсюда вы не можете видеть прилавок слишком хорошо из-за толп любопытных искателей приключений, приближающихся к нему. Кажется, что это немного хуже для износа, но невероятно долговечно, выдерживая требования очень многих исследователей, работающих в тяжелых условиях.");
				return true;
		}
	}

	看(room, mobile, input) {
		switch(input[0]) {
			case "计数器":
			libs.Output.toMobile(mobile.id, "由于好奇的冒险家挤在一起，你无法从这里看到柜台。 这件衣服看起来有点差，但非常耐用，可以满足这么多粗糙和翻滚的探险家的需求。");
				return true;
		}
	}

	west(room, mobile, input) {
		world.mud_moveMobile(mobile.id, this.id, "ZebedeeAdventurerLounge", "leaves west");
		return true;
	}

	east(room, mobile, input) {
		world.mud_moveMobile(mobile.id, this.id, "ZebedeeAdventurerHelp", "leaves east");
		return true;
	}

	north(room, mobile, input) {
		world.mud_moveMobile(mobile.id, this.id, "ZebedeeCormallenRoad4", "leaves the guild");
		return true;
	}

	up(room, mobile, input) {
		world.mud_moveMobile(mobile.id, this.id, "ZebedeeAdventurerTraining", "heads south up the stairs");
		return true;
	}
};
